@@ -63,7 +63,7 @@ class ACall:
         self.session = None
 
     async def call(self, path, method="GET", headers={}, params={}, json={}, no_auth=False):
-        print(method + " request at " + path)
+        #print(method + " request at " + path)
 
         if no_auth:
             return await self._call(path, method, headers, params, json)
@@ -160,7 +160,7 @@ class Call:
         self.b64_auth = None
 
     def call(self, path, method="GET", headers={}, params={}, json={}, no_auth=False):
-        print(method + " request at " + path)
+        #print(method + " request at " + path)
 
         headers["user-agent"] = ""
 
